pub struct DbArgs {
pub db_connection_pool_size: u32,
pub db_connection_timeout_ms: u64,
pub db_statement_timeout_ms: Option<u64>,
pub tls_verify_cert: bool,
pub tls_ca_cert_path: Option<PathBuf>,
}Fields
db_connection_pool_size: u32Number of connections to keep in the pool.
db_connection_timeout_ms: u64Time spent waiting for a connection from the pool to become available, in milliseconds.
db_statement_timeout_ms: Option<u64>Time spent waiting for statements to complete, in milliseconds.
tls_verify_cert: boolEnable server certificate verification. By default, this is set to false to match the default behavior of libpq.
tls_ca_cert_path: Option<PathBuf>Path to a custom CA certificate to use for server certificate verification.
Implementations
Sourceimpl DbArgs
impl DbArgs
pub fn connection_timeout(&self) -> Duration
pub fn statement_timeout(&self) -> Option<Duration>